@@ -2,6 +2,7 @@ import base64
 import logging
 import os
 import unittest
+import time
 
 from tonclient.errors import TonException
 from tonclient.test.test_abi import SAMPLES_DIR
@@ -10,6 +11,14 @@ from tonclient.types import (
     Abi,
     DeploySet,
     CallSet,
+    MessageMonitoringParams,
+    MessageSendingParams,
+    MonitoredMessage,
+    ParamsOfCancelMonitor,
+    ParamsOfGetBocHash,
+    ParamsOfGetMonitorInfo,
+    ParamsOfMonitorMessages,
+    ParamsOfSendMessages,
     Signer,
     FunctionHeader,
     ParamsOfEncodeMessage,
@@ -211,3 +220,100 @@ class TestTonProcessingAsyncCore(unittest.TestCase):
         logging.info('Wait message events:')
         for e in events:
             logging.info(e.type)
+
+    def test_send_messages_monitoring(self):
+        wait_until = int(time.time()) + 10
+
+        # Create deploy messages
+        messages = []
+        for _ in range(5):
+            keypair = async_core_client.crypto.generate_random_sign_keys()
+            signer = Signer.Keys(keys=keypair)
+            call_set = CallSet(
+                function_name='constructor',
+                header=FunctionHeader(pubkey=keypair.public),
+            )
+            encode_params = ParamsOfEncodeMessage(
+                abi=self.events_abi,
+                signer=signer,
+                deploy_set=self.deploy_set,
+                call_set=call_set,
+            )
+            encoded = async_core_client.abi.encode_message(params=encode_params)
+            send_grams(address=encoded.address)
+            messages.append(encoded)
+
+        # Send messages
+        queue_id = 'test-queue-1'
+        params_msg = [
+            MessageSendingParams(
+                boc=encoded.message, wait_until=wait_until, user_data={'id': 'user_id'}
+            )
+            for encoded in messages
+        ]
+        params = ParamsOfSendMessages(messages=params_msg, monitor_queue=queue_id)
+        result = async_core_client.processing.send_messages(params=params)
+        self.assertEqual(5, len(result.messages))
+        self.assertEqual({'id': 'user_id'}, result.messages[0].user_data)
+        self.assertEqual(messages[0].message, result.messages[0].message.boc)
+
+        # Get monitor info
+        params = ParamsOfGetMonitorInfo(queue=queue_id)
+        info = async_core_client.processing.get_monitor_info(params=params)
+        self.assertEqual(5, info.unresolved)
+        self.assertEqual(0, info.resolved)
+
+        # Fetch next monitoring results
+        # It is not supported by node SE yet
+        # params = ParamsOfFetchNextMonitorResults(
+        #     queue=queue_id, wait_mode=MonitorFetchWaitMode.AT_LEAST_ONE
+        # )
+        # result = async_core_client.processing.fetch_next_monitor_results(params=params)
+        # print(result.__dict__)
+
+        # Cancel monitor
+        params = ParamsOfCancelMonitor(queue=queue_id)
+        async_core_client.processing.cancel_monitor(params=params)
+
+    def test_message_monitoring(self):
+        wait_until = int(time.time()) + 10
+        queue_id = 'queue-1'
+
+        # Create deploy messages
+        messages = []
+        for _ in range(5):
+            keypair = async_core_client.crypto.generate_random_sign_keys()
+            signer = Signer.Keys(keys=keypair)
+            call_set = CallSet(
+                function_name='constructor',
+                header=FunctionHeader(pubkey=keypair.public),
+            )
+            encode_params = ParamsOfEncodeMessage(
+                abi=self.events_abi,
+                signer=signer,
+                deploy_set=self.deploy_set,
+                call_set=call_set,
+            )
+            encoded = async_core_client.abi.encode_message(params=encode_params)
+            send_grams(address=encoded.address)
+
+            result = async_core_client.boc.get_boc_hash(
+                params=ParamsOfGetBocHash(boc=encoded.message)
+            )
+            message = MonitoredMessage.HashAddress(
+                hash=result.hash, address=encoded.address
+            )
+            messages.append(
+                MessageMonitoringParams(message=message, wait_until=wait_until)
+            )
+
+        # Monitor messages
+        params = ParamsOfMonitorMessages(queue=queue_id, messages=messages)
+        async_core_client.processing.monitor_messages(params=params)
+
+        # Fetch next monitoring results
+        # It is not supported by node SE yet
+
+        # Cancel monitor
+        params = ParamsOfCancelMonitor(queue=queue_id)
+        async_core_client.processing.cancel_monitor(params=params)
